<?php

namespace App\Services\Api;

use App\Repositories\Transformers\Rhawn\Bhua\BrandsTransformer;
use App\Repositories\Transformers\Rhawn\Bhua\ProductsTransformer;
use App\Rhawn\Services\BhuaCustomerService;
use App\Rhawn\Services\BhuaProductService;
use App\Support\Facades\SimpleLogs;
use Illuminate\Support\Facades\DB;

class BhuaProductsService
{
    public function __construct()
    {
        $this->bhuaProductService = app(BhuaProductService::class);
        $this->bhuaCustomerService = app(BhuaCustomerService::class);
    }

    public function getAllBrands($requestParams)
    {
        $offset = !isset($requestParams['page_size']) || empty($requestParams['page_size']) ? 2000 : $requestParams['page_size'];
        if($offset > 200){
            $offset = 200;
        }
        $pageNo = !isset($requestParams['page_no']) || empty($requestParams['page_no']) ? 1 : $requestParams['page_no'];
        $limit = $pageNo == 1 ? 0 : $pageNo * $offset;
        try{
            $where = [];
            $brandsList = $this->bhuaProductService->getBrandsList($where,$offset,$limit);
            $brandsTotal = 0;
            if($brandsList){
                $brandsList = app(BrandsTransformer::class)->transform($brandsList);
                $brandsTotal = $this->bhuaProductService->brandsRepository->count($where);
            }

            $dataReturn = [];
            $dataReturn['data'] = $brandsList;
            $dataReturn['total_page'] = ceil($brandsTotal / $offset);
            $dataReturn['page_no'] = $pageNo;

            return $dataReturn;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':getAllBrands','error');
            throw $exception;
        }
    }

    public function getProductsByBrandId($params)
    {
        $offset = !isset($requestParams['page_size']) || empty($requestParams['page_size']) ? 2000 : $requestParams['page_size'];
        if($offset > 200){
            $offset = 200;
        }
        $pageNo = !isset($requestParams['page_no']) || empty($requestParams['page_no']) ? 1 : $requestParams['page_no'];
        $limit = $pageNo == 1 ? 0 : $pageNo * $offset;
        try{
            $brand = $this->bhuaProductService->brandsRepository->getBrandById($params['brand_id']);
            if(!$brand){
                throw new \Exception('502','没找到相应品牌id');
            }
            $products = $this->bhuaProductService->productRepository->getProductsList(['bid' => $params['brand_id']], $offset, $limit);
            $total = 0;
            if($products){
                $products = app(ProductsTransformer::class)->transform($products);
                $brandsTotal = $this->bhuaProductService->brandsRepository->count(['bid' => $params['brand_id']]);
            }

            $dataReturn = [];
            $dataReturn['data'] = $products;
            $dataReturn['total_page'] = ceil($total / $offset);
            $dataReturn['page_no'] = $pageNo;

            return $dataReturn;

        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':getAllBrands','error');
            throw $exception;
        }


    }

}
